#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-form
version:              1.7.0
visibility:           public
id:                   yesod-form-1.7.0-MK5exFvdoI2UH5GBUZOiL
key:                  yesod-form-1.7.0-MK5exFvdoI2UH5GBUZOiL
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).

category:             Web, Yesod
abi:                  19829eb8eabea50d28a781ab1ecb7165
exposed:              True
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types

import-dirs:          /usr/lib/ghc-8.10.5/site-local/yesod-form-1.7.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/yesod-form-1.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/yesod-form-1.7.0
hs-libraries:         HSyesod-form-1.7.0-MK5exFvdoI2UH5GBUZOiL
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB
    blaze-html-0.9.1.2-3gWJOEFN3Rn7Mv2jAJdKwl
    blaze-markup-0.8.2.8-8RebaU3zReM4AoTFuL4PYs
    byteable-0.1.1-Gf4TH6XbSdI4yHpNVK8xgD bytestring-0.10.12.0
    containers-0.6.4.1 data-default-0.7.1.1-5u8NwVJ9HGT30K0bkKsBOX
    email-validate-2.3.2.13-4Do5pTS423H5nxE3J1H2aZ
    network-uri-2.6.4.1-4m8gp52oIfHLdE9VhQrWxs
    persistent-2.13.0.2-La3E9BZccdVB7xnmOANUxr
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe
    shakespeare-2.0.25-9PoqIRIh6zmA0h3TqA8xt9 text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 wai-3.2.3-6NrdunSiuKK6vnccK2cwty
    xss-sanitize-0.3.6-ItGlBaRM6fdJOHrJ1qW6qv
    yesod-core-1.6.20.1-AZEcK2kpTthHerC9UzYV34
    yesod-persistent-1.6.0.7-KpnMvvjUIkRKoiMBxtvjPX

haddock-interfaces:   /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html:         /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

